# BeamNG.AI Dataset

## Risk Factor (RF)

The behavior of BeamNG.AI can be parameterized with a so-called “aggression” factor (Risk Factor) which controls the risk the driver is willing to take in order to decrease the time to reach the designated destination. 

As explained by BeamNG.research developers, low aggression values (e.g., 0.7) result in a smooth driving, while high aggression values (e.g., 1.2 and above) result in an edgy driving, which might even “cut corners.”

We considered for our experiments three different risk factors (1, 1.5, 2), which resulted in drastically different driving behavior from cautious (RF 1) to reckless (RF 2)
